@@ -2,11 +2,13 @@ from gettext import gettext as _
 
 import deskbar.Handler
 from deskbar.DeskbarHistory import get_deskbar_history
+from deskbar.defs import VERSION
 
 HANDLERS = {
 	"HistoryHandler" : {
 		"name": _("History"),
 		"description": _("Recognize previously used searches"),
+		"version": VERSION,
 	}
 }
 
@@ -14,7 +16,7 @@ class HistoryHandler(deskbar.Handler.Handler):
 	def __init__(self):
 		deskbar.Handler.Handler.__init__(self, "stock_redo")
 		
-	def query(self, query, max):
+	def query(self, query):
 		result = []
 		for text, match in get_deskbar_history():
 			if text.startswith(query):
